==> fundaml-0.1.27.tar.gz: fundaml-0.1.27/README.md <==

[![codecov](https://codecov.io/github/tzoght/mltz-base/branch/main/graph/badge.svg?token=UB03POGOUB)](https://codecov.io/github/tzoght/mltz-base)
[![ci-cd](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml/badge.svg?branch=main)](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml) [![Documentation Status](https://readthedocs.org/projects/mltz-base/badge/?version=latest)](https://mltz-base.readthedocs.io/en/latest/?badge=latest) ![PyPI](https://img.shields.io/pypi/v/mltz_base)

# fundaml

The purpose of this module is simply to simplify ML learning and use best practices while developing ML models. 

**Standardization**: The fundaml project is an attempt to standardize the way ML projects are structured within a team or organization, promoting best practices for organization, testing, and documentation.

**Flexibility**: fundaml is designed with flexibility in mind. Users can likely use different parts of the codebase as needed, and extend or modify components to suit their specific requirements.

**Extensibility**: fundaml could be used as a starting point for building more complex, domain-specific machine learning libraries. The name fundaml itself is intended to be a "**base**" or foundation upon which other things can be built.


## Installation

```bash
$ pip install fundaml
```
from  [Pypi repo](https://pypi.org/manage/project/fundaml/releases/)

## Developers

Please visit [DEVELOPERS.md](DEVELOPERS.md) to set the module for contribution 

## Usage

See [docs](/docs/example.ipynb)

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`fundaml` was created by Tony Zoght. It is licensed under the terms of the MIT license.

## Credits

`fundaml` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).


## Code Coverage
* [CodeCov](https://app.codecov.io/github/tzoght/fundaml) 

## Read The Docs
https://fundaml.readthedocs.io/en/latest/?badge=latest

## Github Pages
https://tzoght.github.io/fundaml/

==> fundaml-0.1.30.tar.gz: fundaml-0.1.30/README.md <==

[![codecov](https://codecov.io/github/tzoght/mltz-base/branch/main/graph/badge.svg?token=UB03POGOUB)](https://codecov.io/github/tzoght/mltz-base)
[![ci-cd](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml/badge.svg?branch=main)](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml) [![Documentation Status](https://readthedocs.org/projects/mltz-base/badge/?version=latest)](https://mltz-base.readthedocs.io/en/latest/?badge=latest) ![PyPI](https://img.shields.io/pypi/v/mltz_base)

# fundaml

The purpose of this module is simply to simplify ML learning and use best practices while developing ML models. 

**Standardization**: The fundaml project is an attempt to standardize the way ML projects are structured within a team or organization, promoting best practices for organization, testing, and documentation.

**Flexibility**: fundaml is designed with flexibility in mind. Users can likely use different parts of the codebase as needed, and extend or modify components to suit their specific requirements.

**Extensibility**: fundaml could be used as a starting point for building more complex, domain-specific machine learning libraries. The name fundaml itself is intended to be a "**base**" or foundation upon which other things can be built.


## Installation

```bash
$ pip install fundaml
```
from  [Pypi repo](https://pypi.org/project/fundaml)

## Developers

Please visit [DEVELOPERS.md](https://github.com/tzoght/fundaml/blob/main/DEVELOPERS.md) to set the module for contribution 

## Usage

See [docs](https://github.com/tzoght/fundaml/blob/main/docs/example.ipynb)

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`fundaml` was created by Tony Zoght. It is licensed under the terms of the MIT license.

## Credits

`fundaml` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).


## Code Coverage
* [CodeCov](https://app.codecov.io/github/tzoght/fundaml) 

## Read The Docs
https://fundaml.readthedocs.io/en/latest/?badge=latest

## Github Pages
https://tzoght.github.io/fundaml/
